/// Return the modification time of a file.
///
/// If it is unable to get the modification time from the file system
/// it will default to the current system time.
pub fn get_file_mod_time(path: &std::path::Path)
                         -> std::io::Result<std::time::SystemTime>
{
   let file = std::fs::File::open(path)?;
   let meta = file.metadata()?;

   if meta.is_file()
   {
      return Ok(meta.modified()?);
   }

   Ok(std::time::SystemTime::now())
}

/// Create a new PathBuf that is the same as path but has the base removed if it
/// can.
pub fn strip_path_prefix(path: &std::path::Path, base: &std::path::Path)
                         -> std::path::PathBuf
{
   match &path.strip_prefix(base)
   {
      Ok(rel_path) =>
      {
         let mut final_path = std::path::PathBuf::new();
         final_path.push("./");
         final_path.push(rel_path);
         final_path
      }

      Err(_) => std::path::PathBuf::from(path)
   }
}
